# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.api.role_management_api import RoleManagementApi


class TestRoleManagementApi(unittest.IsolatedAsyncioTestCase):
    """RoleManagementApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = RoleManagementApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_roles_get(self) -> None:
        """Test case for roles_get

        """
        pass

    async def test_roles_grant_role_post(self) -> None:
        """Test case for roles_grant_role_post

        """
        pass

    async def test_roles_has_role_get(self) -> None:
        """Test case for roles_has_role_get

        """
        pass

    async def test_roles_post(self) -> None:
        """Test case for roles_post

        """
        pass

    async def test_roles_revoke_role_post(self) -> None:
        """Test case for roles_revoke_role_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.user_did_item import UserDIDItem

class TestUserDIDItem(unittest.TestCase):
    """UserDIDItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserDIDItem:
        """Test UserDIDItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserDIDItem`
        """
        model = UserDIDItem()
        if include_optional:
            return UserDIDItem(
                id = '',
                uid = '',
                did = '',
                username_vc = '',
                did_type = '',
                created = 1.337
            )
        else:
            return UserDIDItem(
                id = '',
                uid = '',
                did = '',
                username_vc = '',
                did_type = '',
                created = 1.337,
        )
        """

    def testUserDIDItem(self):
        """Test UserDIDItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AccessControlApi",
    "AuthApi",
    "IdentityApi",
    "LicenseApi",
    "MarketplaceApi",
    "PolicyApi",
    "RegisterAiModelApi",
    "RegisterBenchmarkApi",
    "RegisterDatasetApi",
    "RegisterHardwareApi",
    "RewardManagerApi",
    "RoleManagementApi",
    "SystemPauseApi",
    "TokensApi",
    "UsersApi",
    "VcApi",
    "WalletApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Accelerator",
    "AcceptVCRequestBody",
    "AddDelegateBody",
    "AuthenticationContext",
    "AuthenticationContextError",
    "BuyResourceBody",
    "CPU",
    "CPUSpecsItem",
    "ChangeOwnerBody",
    "CheckAccessResponse",
    "Cost",
    "CreateAIModelResponse",
    "CreateBenchmarkResponse",
    "CreateDIDPolicyBody",
    "CreateDatasetResponse",
    "CreateHardwarePolicyBody",
    "CreateHardwareResponse",
    "CreateRoleBody",
    "CreateRoleResponse",
    "DecodeCredentialBody",
    "DefaultSpecItem",
    "DefaultSpecsMemory",
    "DeleteHardwareBody",
    "EditDIDPolicyBody",
    "EditHardwarePolicyBody",
    "Engine",
    "ErrorResponse",
    "GenerateKeyPairBody",
    "GetRegisterAIModelItem",
    "GetRegisterBenchmarkItem",
    "GetRegisterDatasetItem",
    "GetRegisterHardwareItem",
    "GetRewardByRule",
    "GranRoleBody",
    "GrantAccessBody",
    "GrantRevokeIssuerRoleBody",
    "HardwareAccessItem",
    "HardwareAccessList",
    "HardwarePolicyResponse",
    "HardwareSpec",
    "HasRoleResponse",
    "IdentityOwnerResponse",
    "LicenseRequestItem",
    "LicenseRequestList",
    "ListedResourceItem",
    "ListedResourceList",
    "LoginErrorBadRequest",
    "LoginErrorForbidden",
    "LoginRequest",
    "LoginResponse",
    "Memory",
    "MintTokensBody",
    "PauseContractBody",
    "PauseSystemBody",
    "Power",
    "PowerItemDetails",
    "RegisterAIModelBody",
    "RegisterAIModelItem",
    "RegisterAIModelList",
    "RegisterAccessBody",
    "RegisterBenchmarkBody",
    "RegisterBenchmarkItem",
    "RegisterBenchmarkList",
    "RegisterDataSetItem",
    "RegisterDataSetList",
    "RegisterDatasetBody",
    "RegisterHardwareBody",
    "RegisterHardwareItem",
    "RegisterHardwareList",
    "RemoveDIDPolicyBody",
    "RemoveHardwarePolicyBody",
    "RemoveListedResourceBody",
    "RemoveRewardRuleBody",
    "RequestUserLicenseBody",
    "RequestVCBody",
    "RevokeAccessBody",
    "RevokeDelegateBody",
    "RevokeIssuerRoleBody",
    "RevokeLicenseBody",
    "RevokeRoleBody",
    "RewardHistoryItem",
    "RewardHistoryList",
    "RewardManualBody",
    "RewardOffChainBody",
    "RewardOnChainBody",
    "RoleManagementItem",
    "RoleManagementList",
    "SellResourceBody",
    "SetBenchmarkResultBody",
    "SetHardwareBody",
    "SetRewardRuleBody",
    "SignupErrorBadRequest",
    "SignupRequest",
    "SignupResponse",
    "SoftwareSpec",
    "Storage",
    "StorageSpecsItem",
    "SupportedApplication",
    "SupportedApplicationDetails",
    "SystemStatus",
    "UnpauseContractBody",
    "UnpauseSystemBody",
    "UpdateAIModelBody",
    "UpdateDatasetBody",
    "UpdateHardwareBody",
    "UseLicenseItem",
    "UserDIDItem",
    "UserDIDList",
    "UserDIDResolveResponse",
    "UserLicenseList",
    "UserVCItem",
    "UserVCList",
    "VCClaim",
    "VCRequestItem",
    "VCRequestList",
    "ValidateLicenseRequestBody",
    "VerifyCredentialBody",
    "VerifyCredentialResponse",
    "VerifyPresentationBody",
    "WalletChangePasswordBadRequest",
    "WalletChangePasswordBody",
    "WalletCreateBadRequest",
    "WalletCreateBody",
    "WalletEditBadRequest",
    "WalletEditBody",
    "WalletExportBadRequest",
    "WalletExportBody",
    "WalletExportResponse",
    "WalletInfo",
]

# import apis into sdk package
from daiedge_middleware_client.api.access_control_api import AccessControlApi as AccessControlApi
from daiedge_middleware_client.api.auth_api import AuthApi as AuthApi
from daiedge_middleware_client.api.identity_api import IdentityApi as IdentityApi
from daiedge_middleware_client.api.license_api import LicenseApi as LicenseApi
from daiedge_middleware_client.api.marketplace_api import MarketplaceApi as MarketplaceApi
from daiedge_middleware_client.api.policy_api import PolicyApi as PolicyApi
from daiedge_middleware_client.api.register_ai_model_api import RegisterAiModelApi as RegisterAiModelApi
from daiedge_middleware_client.api.register_benchmark_api import RegisterBenchmarkApi as RegisterBenchmarkApi
from daiedge_middleware_client.api.register_dataset_api import RegisterDatasetApi as RegisterDatasetApi
from daiedge_middleware_client.api.register_hardware_api import RegisterHardwareApi as RegisterHardwareApi
from daiedge_middleware_client.api.reward_manager_api import RewardManagerApi as RewardManagerApi
from daiedge_middleware_client.api.role_management_api import RoleManagementApi as RoleManagementApi
from daiedge_middleware_client.api.system_pause_api import SystemPauseApi as SystemPauseApi
from daiedge_middleware_client.api.tokens_api import TokensApi as TokensApi
from daiedge_middleware_client.api.users_api import UsersApi as UsersApi
from daiedge_middleware_client.api.vc_api import VcApi as VcApi
from daiedge_middleware_client.api.wallet_api import WalletApi as WalletApi

# import ApiClient
from daiedge_middleware_client.api_response import ApiResponse as ApiResponse
from daiedge_middleware_client.api_client import ApiClient as ApiClient
from daiedge_middleware_client.configuration import Configuration as Configuration
from daiedge_middleware_client.exceptions import OpenApiException as OpenApiException
from daiedge_middleware_client.exceptions import ApiTypeError as ApiTypeError
from daiedge_middleware_client.exceptions import ApiValueError as ApiValueError
from daiedge_middleware_client.exceptions import ApiKeyError as ApiKeyError
from daiedge_middleware_client.exceptions import ApiAttributeError as ApiAttributeError
from daiedge_middleware_client.exceptions import ApiException as ApiException

# import models into sdk package
from daiedge_middleware_client.models.accelerator import Accelerator as Accelerator
from daiedge_middleware_client.models.accept_vc_request_body import AcceptVCRequestBody as AcceptVCRequestBody
from daiedge_middleware_client.models.add_delegate_body import AddDelegateBody as AddDelegateBody
from daiedge_middleware_client.models.authentication_context import AuthenticationContext as AuthenticationContext
from daiedge_middleware_client.models.authentication_context_error import AuthenticationContextError as AuthenticationContextError
from daiedge_middleware_client.models.buy_resource_body import BuyResourceBody as BuyResourceBody
from daiedge_middleware_client.models.cpu import CPU as CPU
from daiedge_middleware_client.models.cpu_specs_item import CPUSpecsItem as CPUSpecsItem
from daiedge_middleware_client.models.change_owner_body import ChangeOwnerBody as ChangeOwnerBody
from daiedge_middleware_client.models.check_access_response import CheckAccessResponse as CheckAccessResponse
from daiedge_middleware_client.models.cost import Cost as Cost
from daiedge_middleware_client.models.create_ai_model_response import CreateAIModelResponse as CreateAIModelResponse
from daiedge_middleware_client.models.create_benchmark_response import CreateBenchmarkResponse as CreateBenchmarkResponse
from daiedge_middleware_client.models.create_did_policy_body import CreateDIDPolicyBody as CreateDIDPolicyBody
from daiedge_middleware_client.models.create_dataset_response import CreateDatasetResponse as CreateDatasetResponse
from daiedge_middleware_client.models.create_hardware_policy_body import CreateHardwarePolicyBody as CreateHardwarePolicyBody
from daiedge_middleware_client.models.create_hardware_response import CreateHardwareResponse as CreateHardwareResponse
from daiedge_middleware_client.models.create_role_body import CreateRoleBody as CreateRoleBody
from daiedge_middleware_client.models.create_role_response import CreateRoleResponse as CreateRoleResponse
from daiedge_middleware_client.models.decode_credential_body import DecodeCredentialBody as DecodeCredentialBody
from daiedge_middleware_client.models.default_spec_item import DefaultSpecItem as DefaultSpecItem
from daiedge_middleware_client.models.default_specs_memory import DefaultSpecsMemory as DefaultSpecsMemory
from daiedge_middleware_client.models.delete_hardware_body import DeleteHardwareBody as DeleteHardwareBody
from daiedge_middleware_client.models.edit_did_policy_body import EditDIDPolicyBody as EditDIDPolicyBody
from daiedge_middleware_client.models.edit_hardware_policy_body import EditHardwarePolicyBody as EditHardwarePolicyBody
from daiedge_middleware_client.models.engine import Engine as Engine
from daiedge_middleware_client.models.error_response import ErrorResponse as ErrorResponse
from daiedge_middleware_client.models.generate_key_pair_body import GenerateKeyPairBody as GenerateKeyPairBody
from daiedge_middleware_client.models.get_register_ai_model_item import GetRegisterAIModelItem as GetRegisterAIModelItem
from daiedge_middleware_client.models.get_register_benchmark_item import GetRegisterBenchmarkItem as GetRegisterBenchmarkItem
from daiedge_middleware_client.models.get_register_dataset_item import GetRegisterDatasetItem as GetRegisterDatasetItem
from daiedge_middleware_client.models.get_register_hardware_item import GetRegisterHardwareItem as GetRegisterHardwareItem
from daiedge_middleware_client.models.get_reward_by_rule import GetRewardByRule as GetRewardByRule
from daiedge_middleware_client.models.gran_role_body import GranRoleBody as GranRoleBody
from daiedge_middleware_client.models.grant_access_body import GrantAccessBody as GrantAccessBody
from daiedge_middleware_client.models.grant_revoke_issuer_role_body import GrantRevokeIssuerRoleBody as GrantRevokeIssuerRoleBody
from daiedge_middleware_client.models.hardware_access_item import HardwareAccessItem as HardwareAccessItem
from daiedge_middleware_client.models.hardware_access_list import HardwareAccessList as HardwareAccessList
from daiedge_middleware_client.models.hardware_policy_response import HardwarePolicyResponse as HardwarePolicyResponse
from daiedge_middleware_client.models.hardware_spec import HardwareSpec as HardwareSpec
from daiedge_middleware_client.models.has_role_response import HasRoleResponse as HasRoleResponse
from daiedge_middleware_client.models.identity_owner_response import IdentityOwnerResponse as IdentityOwnerResponse
from daiedge_middleware_client.models.license_request_item import LicenseRequestItem as LicenseRequestItem
from daiedge_middleware_client.models.license_request_list import LicenseRequestList as LicenseRequestList
from daiedge_middleware_client.models.listed_resource_item import ListedResourceItem as ListedResourceItem
from daiedge_middleware_client.models.listed_resource_list import ListedResourceList as ListedResourceList
from daiedge_middleware_client.models.login_error_bad_request import LoginErrorBadRequest as LoginErrorBadRequest
from daiedge_middleware_client.models.login_error_forbidden import LoginErrorForbidden as LoginErrorForbidden
from daiedge_middleware_client.models.login_request import LoginRequest as LoginRequest
from daiedge_middleware_client.models.login_response import LoginResponse as LoginResponse
from daiedge_middleware_client.models.memory import Memory as Memory
from daiedge_middleware_client.models.mint_tokens_body import MintTokensBody as MintTokensBody
from daiedge_middleware_client.models.pause_contract_body import PauseContractBody as PauseContractBody
from daiedge_middleware_client.models.pause_system_body import PauseSystemBody as PauseSystemBody
from daiedge_middleware_client.models.power import Power as Power
from daiedge_middleware_client.models.power_item_details import PowerItemDetails as PowerItemDetails
from daiedge_middleware_client.models.register_ai_model_body import RegisterAIModelBody as RegisterAIModelBody
from daiedge_middleware_client.models.register_ai_model_item import RegisterAIModelItem as RegisterAIModelItem
from daiedge_middleware_client.models.register_ai_model_list import RegisterAIModelList as RegisterAIModelList
from daiedge_middleware_client.models.register_access_body import RegisterAccessBody as RegisterAccessBody
from daiedge_middleware_client.models.register_benchmark_body import RegisterBenchmarkBody as RegisterBenchmarkBody
from daiedge_middleware_client.models.register_benchmark_item import RegisterBenchmarkItem as RegisterBenchmarkItem
from daiedge_middleware_client.models.register_benchmark_list import RegisterBenchmarkList as RegisterBenchmarkList
from daiedge_middleware_client.models.register_data_set_item import RegisterDataSetItem as RegisterDataSetItem
from daiedge_middleware_client.models.register_data_set_list import RegisterDataSetList as RegisterDataSetList
from daiedge_middleware_client.models.register_dataset_body import RegisterDatasetBody as RegisterDatasetBody
from daiedge_middleware_client.models.register_hardware_body import RegisterHardwareBody as RegisterHardwareBody
from daiedge_middleware_client.models.register_hardware_item import RegisterHardwareItem as RegisterHardwareItem
from daiedge_middleware_client.models.register_hardware_list import RegisterHardwareList as RegisterHardwareList
from daiedge_middleware_client.models.remove_did_policy_body import RemoveDIDPolicyBody as RemoveDIDPolicyBody
from daiedge_middleware_client.models.remove_hardware_policy_body import RemoveHardwarePolicyBody as RemoveHardwarePolicyBody
from daiedge_middleware_client.models.remove_listed_resource_body import RemoveListedResourceBody as RemoveListedResourceBody
from daiedge_middleware_client.models.remove_reward_rule_body import RemoveRewardRuleBody as RemoveRewardRuleBody
from daiedge_middleware_client.models.request_user_license_body import RequestUserLicenseBody as RequestUserLicenseBody
from daiedge_middleware_client.models.request_vc_body import RequestVCBody as RequestVCBody
from daiedge_middleware_client.models.revoke_access_body import RevokeAccessBody as RevokeAccessBody
from daiedge_middleware_client.models.revoke_delegate_body import RevokeDelegateBody as RevokeDelegateBody
from daiedge_middleware_client.models.revoke_issuer_role_body import RevokeIssuerRoleBody as RevokeIssuerRoleBody
from daiedge_middleware_client.models.revoke_license_body import RevokeLicenseBody as RevokeLicenseBody
from daiedge_middleware_client.models.revoke_role_body import RevokeRoleBody as RevokeRoleBody
from daiedge_middleware_client.models.reward_history_item import RewardHistoryItem as RewardHistoryItem
from daiedge_middleware_client.models.reward_history_list import RewardHistoryList as RewardHistoryList
from daiedge_middleware_client.models.reward_manual_body import RewardManualBody as RewardManualBody
from daiedge_middleware_client.models.reward_off_chain_body import RewardOffChainBody as RewardOffChainBody
from daiedge_middleware_client.models.reward_on_chain_body import RewardOnChainBody as RewardOnChainBody
from daiedge_middleware_client.models.role_management_item import RoleManagementItem as RoleManagementItem
from daiedge_middleware_client.models.role_management_list import RoleManagementList as RoleManagementList
from daiedge_middleware_client.models.sell_resource_body import SellResourceBody as SellResourceBody
from daiedge_middleware_client.models.set_benchmark_result_body import SetBenchmarkResultBody as SetBenchmarkResultBody
from daiedge_middleware_client.models.set_hardware_body import SetHardwareBody as SetHardwareBody
from daiedge_middleware_client.models.set_reward_rule_body import SetRewardRuleBody as SetRewardRuleBody
from daiedge_middleware_client.models.signup_error_bad_request import SignupErrorBadRequest as SignupErrorBadRequest
from daiedge_middleware_client.models.signup_request import SignupRequest as SignupRequest
from daiedge_middleware_client.models.signup_response import SignupResponse as SignupResponse
from daiedge_middleware_client.models.software_spec import SoftwareSpec as SoftwareSpec
from daiedge_middleware_client.models.storage import Storage as Storage
from daiedge_middleware_client.models.storage_specs_item import StorageSpecsItem as StorageSpecsItem
from daiedge_middleware_client.models.supported_application import SupportedApplication as SupportedApplication
from daiedge_middleware_client.models.supported_application_details import SupportedApplicationDetails as SupportedApplicationDetails
from daiedge_middleware_client.models.system_status import SystemStatus as SystemStatus
from daiedge_middleware_client.models.unpause_contract_body import UnpauseContractBody as UnpauseContractBody
from daiedge_middleware_client.models.unpause_system_body import UnpauseSystemBody as UnpauseSystemBody
from daiedge_middleware_client.models.update_ai_model_body import UpdateAIModelBody as UpdateAIModelBody
from daiedge_middleware_client.models.update_dataset_body import UpdateDatasetBody as UpdateDatasetBody
from daiedge_middleware_client.models.update_hardware_body import UpdateHardwareBody as UpdateHardwareBody
from daiedge_middleware_client.models.use_license_item import UseLicenseItem as UseLicenseItem
from daiedge_middleware_client.models.user_did_item import UserDIDItem as UserDIDItem
from daiedge_middleware_client.models.user_did_list import UserDIDList as UserDIDList
from daiedge_middleware_client.models.user_did_resolve_response import UserDIDResolveResponse as UserDIDResolveResponse
from daiedge_middleware_client.models.user_license_list import UserLicenseList as UserLicenseList
from daiedge_middleware_client.models.user_vc_item import UserVCItem as UserVCItem
from daiedge_middleware_client.models.user_vc_list import UserVCList as UserVCList
from daiedge_middleware_client.models.vc_claim import VCClaim as VCClaim
from daiedge_middleware_client.models.vc_request_item import VCRequestItem as VCRequestItem
from daiedge_middleware_client.models.vc_request_list import VCRequestList as VCRequestList
from daiedge_middleware_client.models.validate_license_request_body import ValidateLicenseRequestBody as ValidateLicenseRequestBody
from daiedge_middleware_client.models.verify_credential_body import VerifyCredentialBody as VerifyCredentialBody
from daiedge_middleware_client.models.verify_credential_response import VerifyCredentialResponse as VerifyCredentialResponse
from daiedge_middleware_client.models.verify_presentation_body import VerifyPresentationBody as VerifyPresentationBody
from daiedge_middleware_client.models.wallet_change_password_bad_request import WalletChangePasswordBadRequest as WalletChangePasswordBadRequest
from daiedge_middleware_client.models.wallet_change_password_body import WalletChangePasswordBody as WalletChangePasswordBody
from daiedge_middleware_client.models.wallet_create_bad_request import WalletCreateBadRequest as WalletCreateBadRequest
from daiedge_middleware_client.models.wallet_create_body import WalletCreateBody as WalletCreateBody
from daiedge_middleware_client.models.wallet_edit_bad_request import WalletEditBadRequest as WalletEditBadRequest
from daiedge_middleware_client.models.wallet_edit_body import WalletEditBody as WalletEditBody
from daiedge_middleware_client.models.wallet_export_bad_request import WalletExportBadRequest as WalletExportBadRequest
from daiedge_middleware_client.models.wallet_export_body import WalletExportBody as WalletExportBody
from daiedge_middleware_client.models.wallet_export_response import WalletExportResponse as WalletExportResponse
from daiedge_middleware_client.models.wallet_info import WalletInfo as WalletInfo




# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.api.wallet_api import WalletApi


class TestWalletApi(unittest.IsolatedAsyncioTestCase):
    """WalletApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = WalletApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_wallet_get(self) -> None:
        """Test case for wallet_get

        """
        pass

    async def test_wallet_id_delete(self) -> None:
        """Test case for wallet_id_delete

        """
        pass

    async def test_wallet_id_export_post(self) -> None:
        """Test case for wallet_id_export_post

        """
        pass

    async def test_wallet_id_get(self) -> None:
        """Test case for wallet_id_get

        """
        pass

    async def test_wallet_id_password_post(self) -> None:
        """Test case for wallet_id_password_post

        """
        pass

    async def test_wallet_id_post(self) -> None:
        """Test case for wallet_id_post

        """
        pass

    async def test_wallet_post(self) -> None:
        """Test case for wallet_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.listed_resource_list import ListedResourceList

class TestListedResourceList(unittest.TestCase):
    """ListedResourceList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListedResourceList:
        """Test ListedResourceList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListedResourceList`
        """
        model = ListedResourceList()
        if include_optional:
            return ListedResourceList(
                resources = [
                    daiedge_middleware_client.models.listed_resource_item.ListedResourceItem(
                        id = '', 
                        resource_id = '', 
                        price = 1.337, 
                        resource_type = 'ai_model', 
                        buyer = '', 
                        bought = True, 
                        created = 1.337, 
                        bought_date = 1.337, )
                    ],
                page = 1.337,
                total_pages = 1.337,
                total = 1.337
            )
        else:
            return ListedResourceList(
                resources = [
                    daiedge_middleware_client.models.listed_resource_item.ListedResourceItem(
                        id = '', 
                        resource_id = '', 
                        price = 1.337, 
                        resource_type = 'ai_model', 
                        buyer = '', 
                        bought = True, 
                        created = 1.337, 
                        bought_date = 1.337, )
                    ],
        )
        """

    def testListedResourceList(self):
        """Test ListedResourceList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
